@@ -1,23 +1,23 @@
 # -*- coding: UTF-8 -*-
 from decorated.base import function
 from decorated.decorators import events
-from logging import getLogger, DEBUG, INFO, WARN, ERROR, CRITICAL
 from loggingd import util
-from loggingd.decorators import log_enter, log_return, log_error
+from loggingd.decorators import LogEnter, LogError, LogExit, LogReturn
 from loggingd.util import disable_module_log
 import logging
 
-DEBUG = DEBUG
-INFO = INFO
-WARN = WARN
-ERROR = ERROR
-CRITICAL = CRITICAL
+DEBUG = logging.DEBUG
+INFO = logging.INFO
+WARN = logging.WARN
+ERROR = logging.ERROR
+CRITICAL = logging.CRITICAL
+getLogger = logging.getLogger
 
 disable_module_log = disable_module_log
-getLogger = getLogger
-log_enter = log_enter
-log_error = log_error
-log_return = log_return
+log_enter = LogEnter
+log_error = LogError
+log_exit = LogExit
+log_return = LogReturn
 
 def add_console_handler(level, fmt='%(message)s'):
     handler = logging.StreamHandler()
